@@ -1,4 +1,11 @@
-import pygame
+from sys import exit
+
+try:
+    import pygame
+except ImportError:
+    print("Please install 'denver-api[gui-tools]' using pip to use this")
+    exit(1)
+import os
 import argparse
 import denverapi.ctext
 
@@ -55,7 +62,7 @@ DARKER_GREY = (40, 40, 40)
 
 # grid data
 grid = [[None for _ in range(40)] for _ in range(80)]
-grid_render_font = pygame.font.Font(f"{__file__}/../_cpic_editor/consola.ttf", 18)
+grid_render_font = pygame.font.Font(os.path.abspath(f"{__file__}/../_cpic_editor/consola.ttf"), 18)
 
 
 def generate_color_pallet(colors: list, selected: int):
@@ -131,7 +138,7 @@ def main(args):
         file_name = args.file
     if file_name is None:
         raise ValueError("Please specify either one of the options")
-    font = pygame.font.Font(f"{__file__}/../_cpic_editor/consola.ttf", 13)
+    font = pygame.font.Font(os.path.abspath(f"{__file__}/../_cpic_editor/consola.ttf"), 13)
     fore_color_label = font.render("Fore Color", True, ORIGINAL_WHITE)
     fore_color_label_rect: pygame.Rect = fore_color_label.get_rect()
     fore_color_label_rect.midtop = (600, 2)
